@@ -7,13 +7,13 @@
 #include "TransactionModel.h"
 
 // Qt includes
+#include <KLocalizedString>
 #include <QDebug>
 #include <QMetaProperty>
-#include <KLocalizedString>
 
 // Own includes
-#include "resources/AbstractResource.h"
 #include "libdiscover_debug.h"
+#include "resources/AbstractResource.h"
 
 Q_GLOBAL_STATIC(TransactionModel, globalTransactionModel)
 
@@ -30,7 +30,7 @@ TransactionModel::TransactionModel(QObject *parent)
     connect(this, &TransactionModel::countChanged, this, &TransactionModel::progressChanged);
 }
 
-QHash< int, QByteArray > TransactionModel::roleNames() const
+QHash<int, QByteArray> TransactionModel::roleNames() const
 {
     QHash<int, QByteArray> roles;
     roles[TransactionRoleRole] = "transactionRole";
@@ -95,9 +95,9 @@ QVariant TransactionModel::data(const QModelIndex &index, int role) const
         }
         break;
     case TransactionRole:
-        return QVariant::fromValue<QObject*>(trans);
+        return QVariant::fromValue<QObject *>(trans);
     case ResourceRole:
-        return QVariant::fromValue<QObject*>(trans->resource());
+        return QVariant::fromValue<QObject *>(trans->resource());
     }
 
     return QVariant();
@@ -107,7 +107,7 @@ Transaction *TransactionModel::transactionFromResource(AbstractResource *resourc
 {
     Transaction *ret = nullptr;
 
-    Q_FOREACH (Transaction *trans, m_transactions) {
+    for (Transaction *trans : qAsConst(m_transactions)) {
         if (trans->resource() == resource) {
             ret = trans;
             break;
@@ -134,25 +134,36 @@ QModelIndex TransactionModel::indexOf(AbstractResource *res) const
 
 void TransactionModel::addTransaction(Transaction *trans)
 {
-    if(!trans)
+    if (!trans)
         return;
 
     if (m_transactions.contains(trans))
         return;
 
     if (m_transactions.isEmpty())
-        emit startingFirstTransaction();
+        Q_EMIT startingFirstTransaction();
 
     int before = m_transactions.size();
     beginInsertRows(QModelIndex(), before, before + 1);
     m_transactions.append(trans);
+
+    if (before == 0) { // Should emit before count changes
+        Q_EMIT mainTransactionTextChanged();
+    }
     endInsertRows();
 
-    connect(trans, &Transaction::statusChanged, this, [this](){ transactionChanged(StatusTextRole); });
-    connect(trans, &Transaction::cancellableChanged, this, [this](){ transactionChanged(CancellableRole); });
-    connect(trans, &Transaction::progressChanged, this, [this](){ transactionChanged(ProgressRole); Q_EMIT progressChanged(); });
+    connect(trans, &Transaction::statusChanged, this, [this]() {
+        transactionChanged(StatusTextRole);
+    });
+    connect(trans, &Transaction::cancellableChanged, this, [this]() {
+        transactionChanged(CancellableRole);
+    });
+    connect(trans, &Transaction::progressChanged, this, [this]() {
+        transactionChanged(ProgressRole);
+        Q_EMIT progressChanged();
+    });
 
-    emit transactionAdded(trans);
+    Q_EMIT transactionAdded(trans);
 }
 
 void TransactionModel::removeTransaction(Transaction *trans)
@@ -160,7 +171,7 @@ void TransactionModel::removeTransaction(Transaction *trans)
     Q_ASSERT(trans);
     trans->deleteLater();
     int r = m_transactions.indexOf(trans);
-    if (r<0) {
+    if (r < 0) {
         qCWarning(LIBDISCOVER_LOG) << "transaction not part of the model" << trans;
         return;
     }
@@ -171,27 +182,36 @@ void TransactionModel::removeTransaction(Transaction *trans)
     m_transactions.removeAt(r);
     endRemoveRows();
 
-    emit transactionRemoved(trans);
+    Q_EMIT transactionRemoved(trans);
     if (m_transactions.isEmpty())
-        emit lastTransactionFinished();
+        Q_EMIT lastTransactionFinished();
+
+    if (r == 0) {
+        Q_EMIT mainTransactionTextChanged();
+    }
 }
 
 void TransactionModel::transactionChanged(int role)
 {
     Transaction *trans = qobject_cast<Transaction *>(sender());
     QModelIndex transIdx = indexOf(trans);
-    emit dataChanged(transIdx, transIdx, {role});
+    Q_EMIT dataChanged(transIdx, transIdx, {role});
 }
 
 int TransactionModel::progress() const
 {
     int sum = 0;
     int count = 0;
-    foreach(Transaction* t, m_transactions) {
+    for (Transaction *t : qAsConst(m_transactions)) {
         if (t->isActive() && t->isVisible()) {
             sum += t->progress();
             ++count;
         }
     }
-    return count==0 ? 0 : sum / count;
+    return count == 0 ? 0 : sum / count;
+}
+
+QString TransactionModel::mainTransactionText() const
+{
+    return m_transactions.isEmpty() ? QString() : m_transactions.constFirst()->name();
 }
