@@ -18,6 +18,7 @@ class DISCOVERCOMMON_EXPORT TransactionModel : public QAbstractListModel
     Q_OBJECT
     Q_PROPERTY(int progress READ progress NOTIFY progressChanged)
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
+    Q_PROPERTY(QString mainTransactionText READ mainTransactionText NOTIFY mainTransactionTextChanged)
 public:
     enum Roles {
         TransactionRoleRole = Qt::UserRole,
@@ -26,7 +27,7 @@ public:
         ProgressRole,
         StatusTextRole,
         ResourceRole,
-        TransactionRole
+        TransactionRole,
     };
 
     explicit TransactionModel(QObject *parent = nullptr);
@@ -44,21 +45,30 @@ public:
     void addTransaction(Transaction *trans);
     void removeTransaction(Transaction *trans);
 
-    bool contains(Transaction* transaction) const { return m_transactions.contains(transaction); }
+    bool contains(Transaction *transaction) const
+    {
+        return m_transactions.contains(transaction);
+    }
     int progress() const;
-    QVector<Transaction *> transactions() const { return m_transactions; }
+    QVector<Transaction *> transactions() const
+    {
+        return m_transactions;
+    }
+
+    QString mainTransactionText() const;
 
 private:
     QVector<Transaction *> m_transactions;
-    
+
 Q_SIGNALS:
     void startingFirstTransaction();
     void lastTransactionFinished();
     void transactionAdded(Transaction *trans);
-    void transactionRemoved(Transaction* trans);
+    void transactionRemoved(Transaction *trans);
     void countChanged();
     void progressChanged();
-    void proceedRequest(Transaction* transaction, const QString &title, const QString &description);
+    void proceedRequest(Transaction *transaction, const QString &title, const QString &description);
+    void mainTransactionTextChanged();
 
 private Q_SLOTS:
     void transactionChanged(int role);
