@@ -7,25 +7,24 @@
 #include "DummyBackend.h"
 #include "DummyResource.h"
 #include "DummyReviewsBackend.h"
-#include "DummyTransaction.h"
 #include "DummySourcesBackend.h"
-#include <resources/StandardBackendUpdater.h>
-#include <resources/SourcesModel.h>
+#include "DummyTransaction.h"
 #include <Transaction/Transaction.h>
+#include <resources/SourcesModel.h>
+#include <resources/StandardBackendUpdater.h>
 
 #include <KAboutData>
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KConfigGroup>
 #include <KSharedConfig>
 #include <QDebug>
 #include <QThread>
 #include <QTimer>
-#include <QAction>
 
 DISCOVER_BACKEND_PLUGIN(DummyBackend)
 
-DummyBackend::DummyBackend(QObject* parent)
+DummyBackend::DummyBackend(QObject *parent)
     : AbstractResourcesBackend(parent)
     , m_updater(new StandardBackendUpdater(this))
     , m_reviews(new DummyReviewsBackend(this))
@@ -43,32 +42,32 @@ DummyBackend::DummyBackend(QObject* parent)
     SourcesModel::global()->addSourcesBackend(new DummySourcesBackend(this));
 }
 
-void DummyBackend::populate(const QString& n)
+void DummyBackend::populate(const QString &n)
 {
     const int start = m_resources.count();
-    for(int i=start; i<start+m_startElements; i++) {
-        const QString name = n+QLatin1Char(' ')+QString::number(i);
-        DummyResource* res = new DummyResource(name, AbstractResource::Application, this);
-        res->setSize(100+(m_startElements-i));
-        res->setState(AbstractResource::State(1+(i%3)));
+    for (int i = start; i < start + m_startElements; i++) {
+        const QString name = n + QLatin1Char(' ') + QString::number(i);
+        DummyResource *res = new DummyResource(name, AbstractResource::Application, this);
+        res->setSize(100 + (m_startElements - i));
+        res->setState(AbstractResource::State(1 + (i % 3)));
         m_resources.insert(name.toLower(), res);
         connect(res, &DummyResource::stateChanged, this, &DummyBackend::updatesCountChanged);
     }
 
-    for(int i=start; i<start+m_startElements; i++) {
-        const QString name = QLatin1String("addon")+QString::number(i);
-        DummyResource* res = new DummyResource(name, AbstractResource::Addon, this);
-        res->setState(AbstractResource::State(1+(i%3)));
-        res->setSize(300+(m_startElements-i));
+    for (int i = start; i < start + m_startElements; i++) {
+        const QString name = QLatin1String("addon") + QString::number(i);
+        DummyResource *res = new DummyResource(name, AbstractResource::Addon, this);
+        res->setState(AbstractResource::State(1 + (i % 3)));
+        res->setSize(300 + (m_startElements - i));
         m_resources.insert(name, res);
         connect(res, &DummyResource::stateChanged, this, &DummyBackend::updatesCountChanged);
     }
 
-    for(int i=start; i<start+m_startElements; i++) {
-        const QString name = QLatin1String("techie")+QString::number(i);
-        DummyResource* res = new DummyResource(name, AbstractResource::Technical, this);
-        res->setState(AbstractResource::State(1+(i%3)));
-        res->setSize(300+(m_startElements-i));
+    for (int i = start; i < start + m_startElements; i++) {
+        const QString name = QLatin1String("techie") + QString::number(i);
+        DummyResource *res = new DummyResource(name, AbstractResource::Technical, this);
+        res->setState(AbstractResource::State(1 + (i % 3)));
+        res->setSize(300 + (m_startElements - i));
         m_resources.insert(name, res);
         connect(res, &DummyResource::stateChanged, this, &DummyBackend::updatesCountChanged);
     }
@@ -77,8 +76,8 @@ void DummyBackend::populate(const QString& n)
 void DummyBackend::toggleFetching()
 {
     m_fetching = !m_fetching;
-//     qDebug() << "fetching..." << m_fetching;
-    emit fetchingChanged();
+    // qDebug() << "fetching..." << m_fetching;
+    Q_EMIT fetchingChanged();
     if (!m_fetching)
         m_reviews->initialize();
 }
@@ -88,71 +87,72 @@ int DummyBackend::updatesCount() const
     return m_updater->updatesCount();
 }
 
-ResultsStream* DummyBackend::search(const AbstractResourcesBackend::Filters& filter)
+ResultsStream *DummyBackend::search(const AbstractResourcesBackend::Filters &filter)
 {
-    QVector<AbstractResource*> ret;
+    QVector<AbstractResource *> ret;
     if (!filter.resourceUrl.isEmpty())
         return findResourceByPackageName(filter.resourceUrl);
-    else foreach(AbstractResource* r, m_resources) {
-        if (r->type() == AbstractResource::Technical && filter.state != AbstractResource::Upgradeable) {
-            continue;
+    else
+        for (AbstractResource *r : qAsConst(m_resources)) {
+            if (r->type() == AbstractResource::Technical && filter.state != AbstractResource::Upgradeable) {
+                continue;
+            }
+
+            if (r->state() < filter.state)
+                continue;
+
+            if (r->name().contains(filter.search, Qt::CaseInsensitive) || r->comment().contains(filter.search, Qt::CaseInsensitive))
+                ret += r;
         }
-
-        if (r->state() < filter.state)
-            continue;
-
-        if(r->name().contains(filter.search, Qt::CaseInsensitive) || r->comment().contains(filter.search, Qt::CaseInsensitive))
-            ret += r;
-    }
     return new ResultsStream(QStringLiteral("DummyStream"), ret);
 }
 
-ResultsStream * DummyBackend::findResourceByPackageName(const QUrl& search)
+ResultsStream *DummyBackend::findResourceByPackageName(const QUrl &search)
 {
-    if(search.isLocalFile()) {
-        DummyResource* res = new DummyResource(search.fileName(), AbstractResource::Technical, this);
+    if (search.isLocalFile()) {
+        DummyResource *res = new DummyResource(search.fileName(), AbstractResource::Technical, this);
         res->setSize(666);
         res->setState(AbstractResource::None);
         m_resources.insert(res->packageName(), res);
         connect(res, &DummyResource::stateChanged, this, &DummyBackend::updatesCountChanged);
-        return new ResultsStream(QStringLiteral("DummyStream-local"), { res });
+        return new ResultsStream(QStringLiteral("DummyStream-local"), {res});
     }
 
     auto res = search.scheme() == QLatin1String("dummy") ? m_resources.value(search.host().replace(QLatin1Char('.'), QLatin1Char(' '))) : nullptr;
     if (!res) {
         return new ResultsStream(QStringLiteral("DummyStream"), {});
     } else
-        return new ResultsStream(QStringLiteral("DummyStream"), { res });
+        return new ResultsStream(QStringLiteral("DummyStream"), {res});
 }
 
-AbstractBackendUpdater* DummyBackend::backendUpdater() const
+AbstractBackendUpdater *DummyBackend::backendUpdater() const
 {
     return m_updater;
 }
 
-AbstractReviewsBackend* DummyBackend::reviewsBackend() const
+AbstractReviewsBackend *DummyBackend::reviewsBackend() const
 {
     return m_reviews;
 }
 
-Transaction* DummyBackend::installApplication(AbstractResource* app, const AddonList& addons)
+Transaction *DummyBackend::installApplication(AbstractResource *app, const AddonList &addons)
 {
-    return new DummyTransaction(qobject_cast<DummyResource*>(app), addons, Transaction::InstallRole);
+    return new DummyTransaction(qobject_cast<DummyResource *>(app), addons, Transaction::InstallRole);
 }
 
-Transaction* DummyBackend::installApplication(AbstractResource* app)
+Transaction *DummyBackend::installApplication(AbstractResource *app)
 {
-	return new DummyTransaction(qobject_cast<DummyResource*>(app), Transaction::InstallRole);
+    return new DummyTransaction(qobject_cast<DummyResource *>(app), Transaction::InstallRole);
 }
 
-Transaction* DummyBackend::removeApplication(AbstractResource* app)
+Transaction *DummyBackend::removeApplication(AbstractResource *app)
 {
-	return new DummyTransaction(qobject_cast<DummyResource*>(app), Transaction::RemoveRole);
+    return new DummyTransaction(qobject_cast<DummyResource *>(app), Transaction::RemoveRole);
 }
 
 void DummyBackend::checkForUpdates()
 {
-    if(m_fetching)
+    if (m_fetching)
         return;
     toggleFetching();
     populate(QStringLiteral("Moar"));
