@@ -10,17 +10,28 @@
 
 class DummyNotifier : public BackendNotifierModule
 {
-Q_OBJECT
-Q_PLUGIN_METADATA(IID "org.kde.discover.BackendNotifierModule")
-Q_INTERFACES(BackendNotifierModule)
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.discover.BackendNotifierModule")
+    Q_INTERFACES(BackendNotifierModule)
 public:
-    explicit DummyNotifier(QObject* parent = nullptr);
+    explicit DummyNotifier(QObject *parent = nullptr);
     ~DummyNotifier() override;
 
     void recheckSystemUpdateNeeded() override;
-    bool hasSecurityUpdates() override { return false; }
-    bool hasUpdates() override { return false; }
-    bool needsReboot() const override { return false; }
+    bool hasSecurityUpdates() override
+    {
+        return false;
+    }
+
+    bool hasUpdates() override
+    {
+        return false;
+    }
+
+    bool needsReboot() const override
+    {
+        return false;
+    }
 };
 
 #endif
