@@ -94,7 +94,7 @@ Q_SIGNALS: // for tests
 private:
     friend class FlatpakSource;
 
-    void metadataRefreshed();
+    void metadataRefreshed(FlatpakRemote *remote);
     bool flatpakResourceLessThan(AbstractResource *l, AbstractResource *r) const;
     void announceRatingsReady();
     FlatpakInstallation *preferredInstallation() const
@@ -105,6 +105,7 @@ private:
     FlatpakRemote *getFlatpakRemoteByUrl(const QString &url, FlatpakInstallation *installation) const;
     FlatpakResource *getRuntimeForApp(FlatpakResource *resource) const;
     FlatpakResource *resourceForComponent(const AppStream::Component &component, const QSharedPointer<FlatpakSource> &source) const;
+    void checkRepositories(const QMap<QString, QStringList> &names);
 
     void loadAppsFromAppstreamData();
     bool loadAppsFromAppstreamData(FlatpakInstallation *flatpakInstallation);
@@ -122,12 +123,14 @@ private:
     QVector<AbstractResource *> resourcesByAppstreamName(const QString &name) const;
     void acquireFetching(bool f);
     void checkForUpdates(FlatpakInstallation *flatpakInstallation, FlatpakRemote *remote);
+    void createPool(QSharedPointer<FlatpakSource> source);
+    FlatpakRemote *installSource(FlatpakResource *resource);
 
     StandardBackendUpdater *m_updater;
     FlatpakSourcesBackend *m_sources = nullptr;
     QSharedPointer<OdrsReviewsBackend> m_reviews;
     uint m_isFetching = 0;
-    uint m_refreshAppstreamMetadataJobs;
+    QSet<FlatpakRemote *> m_refreshAppstreamMetadataJobs;
     QStringList m_extends;
 
     GCancellable *m_cancellable;
