@@ -1,53 +1,39 @@
 /***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
  *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  ***************************************************************************/
 
-#include <resources/ResourcesModel.h>
-#include <resources/ResourcesProxyModel.h>
-#include <resources/AbstractBackendUpdater.h>
-#include <resources/SourcesModel.h>
 #include <ApplicationAddonsModel.h>
+#include <Category/CategoryModel.h>
 #include <ReviewsBackend/ReviewsModel.h>
 #include <Transaction/TransactionModel.h>
-#include <Category/CategoryModel.h>
+#include <resources/AbstractBackendUpdater.h>
+#include <resources/DiscoverAction.h>
+#include <resources/ResourcesModel.h>
+#include <resources/ResourcesProxyModel.h>
+#include <resources/SourcesModel.h>
 
-#include <qtest.h>
+#include <QTest>
 #include <QtTest>
-#include <QAction>
 
-class FlatpakTest
-    : public QObject
+class FlatpakTest : public QObject
 {
     Q_OBJECT
 public:
-    AbstractResourcesBackend* backendByName(ResourcesModel* m, const QString& name)
+    AbstractResourcesBackend *backendByName(ResourcesModel *m, const QString &name)
     {
-        QVector<AbstractResourcesBackend*> backends = m->backends();
-        foreach(AbstractResourcesBackend* backend, backends) {
-            if(QLatin1String(backend->metaObject()->className()) == name) {
+        const QVector<AbstractResourcesBackend *> backends = m->backends();
+        for (AbstractResourcesBackend *backend : backends) {
+            if (QLatin1String(backend->metaObject()->className()) == name) {
                 return backend;
             }
         }
         return nullptr;
     }
 
-    FlatpakTest(QObject* parent = nullptr): QObject(parent)
+    FlatpakTest(QObject *parent = nullptr)
+        : QObject(parent)
     {
         QStandardPaths::setTestModeEnabled(true);
         qputenv("FLATPAK_TEST_MODE", "ON");
@@ -61,7 +47,7 @@ private Q_SLOTS:
         QDir(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QLatin1String("/discover-flatpak-test")).removeRecursively();
 
         QVERIFY(m_appBackend);
-        while(m_appBackend->isFetching()) {
+        while (m_appBackend->isFetching()) {
             QSignalSpy spy(m_appBackend, &AbstractResourcesBackend::fetchingChanged);
             QVERIFY(spy.wait());
         }
@@ -73,12 +59,12 @@ private Q_SLOTS:
         QCOMPARE(res.count(), 0);
 
         auto m = SourcesModel::global();
-        auto bk = qobject_cast<AbstractSourcesBackend*>(m->index(0, 0).data(SourcesModel::SourcesBackend).value<QObject*>());
+        auto bk = qobject_cast<AbstractSourcesBackend *>(m->index(0, 0).data(SourcesModel::SourcesBackend).value<QObject *>());
 
         QSignalSpy initializedSpy(m_appBackend, SIGNAL(initialized()));
         if (m->rowCount() == 1) {
             QSignalSpy spy(m, &SourcesModel::rowsInserted);
-            qobject_cast<QAction*>(bk->actions().constFirst().value<QObject*>())->trigger();
+            qobject_cast<DiscoverAction *>(bk->actions().constFirst().value<QObject *>())->trigger();
             QVERIFY(spy.count() || spy.wait(20000));
         }
         QVERIFY(initializedSpy.count() || initializedSpy.wait(20000));
@@ -90,8 +76,8 @@ private Q_SLOTS:
     {
         AbstractResourcesBackend::Filters f;
         f.origin = QStringLiteral("flathub");
-        auto resources= getResources(m_appBackend->search(f), true);
-        QVERIFY(resources.count()>0);
+        auto resources = getResources(m_appBackend->search(f), true);
+        QVERIFY(resources.count() > 0);
     }
 
     void testInstallApp()
@@ -127,13 +113,16 @@ private Q_SLOTS:
     }
 
 private:
-    Transaction::Status waitTransaction(Transaction* t) {
+    Transaction::Status waitTransaction(Transaction *t)
+    {
         TransactionModel::global()->addTransaction(t);
         QSignalSpy spyInstalled(TransactionModel::global(), &TransactionModel::transactionRemoved);
         QSignalSpy destructionSpy(t, &QObject::destroyed);
 
         Transaction::Status ret = t->status();
-        connect(TransactionModel::global(), &TransactionModel::transactionRemoved, this, [t, &ret] { ret = t->status(); });
+        connect(TransactionModel::global(), &TransactionModel::transactionRemoved, this, [t, &ret] {
+            ret = t->status();
+        });
         while (t && spyInstalled.count() == 0) {
             qDebug() << "waiting, currently" << ret << spyInstalled.count() << destructionSpy.count();
             spyInstalled.wait(100);
@@ -142,18 +131,20 @@ private:
         return ret;
     }
 
-    QVector<AbstractResource*> getResources(ResultsStream* stream, bool canBeEmpty = true)
+    QVector<AbstractResource *> getResources(ResultsStream *stream, bool canBeEmpty = true)
     {
         Q_ASSERT(stream);
         QSignalSpy spyResources(stream, &ResultsStream::destroyed);
-        QVector<AbstractResource*> resources;
-        connect(stream, &ResultsStream::resourcesFound, this, [&resources](const QVector<AbstractResource*>& res) { resources += res; });
+        QVector<AbstractResource *> resources;
+        connect(stream, &ResultsStream::resourcesFound, this, [&resources](const QVector<AbstractResource *> &res) {
+            resources += res;
+        });
         Q_ASSERT(spyResources.wait(10000));
         Q_ASSERT(!resources.isEmpty() || canBeEmpty);
         return resources;
     }
 
-    QVector<AbstractResource*> getAllResources(AbstractResourcesBackend* backend)
+    QVector<AbstractResource *> getAllResources(AbstractResourcesBackend *backend)
     {
         AbstractResourcesBackend::Filters f;
         if (CategoryModel::global()->rootCategories().isEmpty())
@@ -162,8 +153,8 @@ private:
         return getResources(backend->search(f), true);
     }
 
-    ResourcesModel* m_model;
-    AbstractResourcesBackend* m_appBackend;
+    ResourcesModel *m_model;
+    AbstractResourcesBackend *m_appBackend;
 };
 
 QTEST_MAIN(FlatpakTest)
