@@ -7,27 +7,28 @@
 
 #include "FwupdBackend.h"
 #include "FwupdResource.h"
-#include "FwupdTransaction.h"
 #include "FwupdSourcesBackend.h"
-#include <resources/StandardBackendUpdater.h>
-#include <resources/SourcesModel.h>
+#include "FwupdTransaction.h"
 #include <Transaction/Transaction.h>
+#include <resources/SourcesModel.h>
+#include <resources/StandardBackendUpdater.h>
 
-#include <QtConcurrent>
 #include <KAboutData>
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KConfigGroup>
 #include <KSharedConfig>
+#include <QCoreApplication>
 
 DISCOVER_BACKEND_PLUGIN(FwupdBackend)
 
-FwupdBackend::FwupdBackend(QObject* parent)
+FwupdBackend::FwupdBackend(QObject *parent)
     : AbstractResourcesBackend(parent)
     , client(fwupd_client_new())
     , m_updater(new StandardBackendUpdater(this))
     , m_cancellable(g_cancellable_new())
 {
+    fwupd_client_set_user_agent_for_package(client, "plasma-discover", "1.0");
     connect(m_updater, &StandardBackendUpdater::updatesCountChanged, this, &FwupdBackend::updatesCountChanged);
 
     SourcesModel::global()->addSourcesBackend(new FwupdSourcesBackend(this));
@@ -36,12 +37,12 @@ FwupdBackend::FwupdBackend(QObject* parent)
 
 QMap<GChecksumType, QCryptographicHash::Algorithm> FwupdBackend::gchecksumToQChryptographicHash()
 {
-    static QMap<GChecksumType,QCryptographicHash::Algorithm> map;
+    static QMap<GChecksumType, QCryptographicHash::Algorithm> map;
     if (map.isEmpty()) {
-        map.insert(G_CHECKSUM_SHA1,QCryptographicHash::Sha1);
-        map.insert(G_CHECKSUM_SHA256,QCryptographicHash::Sha256);
-        map.insert(G_CHECKSUM_SHA512,QCryptographicHash::Sha512);
-        map.insert(G_CHECKSUM_MD5,QCryptographicHash::Md5);
+        map.insert(G_CHECKSUM_SHA1, QCryptographicHash::Sha1);
+        map.insert(G_CHECKSUM_SHA256, QCryptographicHash::Sha256);
+        map.insert(G_CHECKSUM_SHA512, QCryptographicHash::Sha512);
+        map.insert(G_CHECKSUM_MD5, QCryptographicHash::Md5);
     }
     return map;
 }
@@ -49,15 +50,12 @@ QMap<GChecksumType, QCryptographicHash::Algorithm> FwupdBackend::gchecksumToQChr
 FwupdBackend::~FwupdBackend()
 {
     g_cancellable_cancel(m_cancellable);
-    if (!m_threadPool.waitForDone(200))
-        qWarning("Could not stop all fwupd threads");
-    m_threadPool.clear();
     g_object_unref(m_cancellable);
 
     g_object_unref(client);
 }
 
-void FwupdBackend::addResourceToList(FwupdResource* res)
+void FwupdBackend::addResource(FwupdResource *res)
 {
     res->setParent(this);
     auto &r = m_resources[res->packageName()];
@@ -69,34 +67,18 @@ void FwupdBackend::addResourceToList(FwupdResource* res)
     Q_ASSERT(m_resources.value(res->packageName()) == res);
 }
 
-FwupdResource * FwupdBackend::createDevice(FwupdDevice *device)
+FwupdResource *FwupdBackend::createRelease(FwupdDevice *device)
 {
-    const QString name = QString::fromUtf8(fwupd_device_get_name(device));
-    FwupdResource* res = new FwupdResource(name, this);
-
-    const QString deviceID = QString::fromUtf8(fwupd_device_get_id(device));
-    res->setId(QStringLiteral("org.fwupd.%1.device").arg(QString(deviceID).replace(QLatin1Char('/'),QLatin1Char('_'))));
-    res->setDeviceId(deviceID);
-    res->setDeviceDetails(device);
-    return res;
-}
-
-FwupdResource * FwupdBackend::createRelease(FwupdDevice *device)
-{
-    FwupdResource* res = createDevice(device);
-
     FwupdRelease *release = fwupd_device_get_release_default(device);
-    res->setId(QString::fromUtf8(fwupd_release_get_appstream_id(release)));
+    FwupdResource *res = new FwupdResource(device, QString::fromUtf8(fwupd_release_get_appstream_id(release)), this);
     res->setReleaseDetails(release);
 
     /* the same as we have already */
-    if (qstrcmp(fwupd_device_get_version(device), fwupd_release_get_version(release)) == 0)
-    {
+    if (qstrcmp(fwupd_device_get_version(device), fwupd_release_get_version(release)) == 0) {
         qWarning() << "Fwupd Error: same firmware version as installed";
     }
 
     return res;
-
 }
 
 void FwupdBackend::addUpdates()
@@ -104,8 +86,7 @@ void FwupdBackend::addUpdates()
     g_autoptr(GError) error = nullptr;
     g_autoptr(GPtrArray) devices = fwupd_client_get_devices(client, m_cancellable, &error);
 
-    if (!devices)
-    {
+    if (!devices) {
         if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_NOTHING_TO_DO))
             qDebug() << "Fwupd Info: No Devices Found";
         else
@@ -113,8 +94,7 @@ void FwupdBackend::addUpdates()
         return;
     }
 
-    for(uint i = 0; i < devices->len && !g_cancellable_is_cancelled(m_cancellable); i++)
-    {
+    for (uint i = 0; i < devices->len && !g_cancellable_is_cancelled(m_cancellable); i++) {
         FwupdDevice *device = (FwupdDevice *)g_ptr_array_index(devices, i);
 
         if (!fwupd_device_has_flag(device, FWUPD_DEVICE_FLAG_SUPPORTED))
@@ -131,15 +111,11 @@ void FwupdBackend::addUpdates()
         if (rels) {
             fwupd_device_add_release(device, (FwupdRelease *)g_ptr_array_index(rels, 0));
             auto res = createApp(device);
-            if (!res)
-            {
+            if (!res) {
                 qWarning() << "Fwupd Error: Cannot Create App From Device" << fwupd_device_get_name(device);
-            }
-            else
-            {
+            } else {
                 QString longdescription;
-                for(uint j = 0; j < rels->len; j++)
-                {
+                for (uint j = 0; j < rels->len; j++) {
                     FwupdRelease *release = (FwupdRelease *)g_ptr_array_index(rels, j);
                     if (!fwupd_release_get_description(release))
                         continue;
@@ -147,7 +123,7 @@ void FwupdBackend::addUpdates()
                     longdescription += QString::fromUtf8(fwupd_release_get_description(release)) + QLatin1Char('\n');
                 }
                 res->setDescription(longdescription);
-                addResourceToList(res);
+                addResource(res);
             }
         } else {
             if (g_error_matches(error2, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED)) {
@@ -176,13 +152,14 @@ QByteArray FwupdBackend::getChecksum(const QString &filename, QCryptographicHash
     return hash.result().toHex();
 }
 
-FwupdResource* FwupdBackend::createApp(FwupdDevice *device)
+FwupdResource *FwupdBackend::createApp(FwupdDevice *device)
 {
     FwupdRelease *release = fwupd_device_get_release_default(device);
     QScopedPointer<FwupdResource> app(createRelease(device));
 
     if (!app->isLiveUpdatable()) {
-        qWarning() << "Fwupd Error: " << app->name() << "[" << app->id() << "]" << "cannot be updated ";
+        qWarning() << "Fwupd Error: " << app->name() << "[" << app->id() << "]"
+                   << "cannot be updated";
         return nullptr;
     }
 
@@ -204,7 +181,7 @@ FwupdResource* FwupdBackend::createApp(FwupdDevice *device)
 
     const QUrl update_uri(QString::fromUtf8(fwupd_release_get_uri(release)));
     if (!update_uri.isValid()) {
-        qWarning() << "Fwupd Error: No Update URI available for" << app->name() <<  "[" << app->id() << "]";
+        qWarning() << "Fwupd Error: No Update URI available for" << app->name() << "[" << app->id() << "]";
         return nullptr;
     }
 
@@ -223,125 +200,18 @@ FwupdResource* FwupdBackend::createApp(FwupdDevice *device)
     return app.take();
 }
 
-bool FwupdBackend::downloadFile(const QUrl &uri, const QString &filename)
-{
-    Q_ASSERT(QThread::currentThread() != QCoreApplication::instance()->thread());
-
-    QScopedPointer<QNetworkAccessManager> manager(new QNetworkAccessManager);
-    QEventLoop loop;
-    QTimer getTimer;
-    connect(&getTimer, &QTimer::timeout, &loop, &QEventLoop::quit);
-    connect(manager.data(), &QNetworkAccessManager::finished, &loop, &QEventLoop::quit);
-    QScopedPointer<QNetworkReply> reply(manager->get(QNetworkRequest(uri)));
-    getTimer.start(600000); // 60 Seconds TimeOout Period
-    loop.exec();
-    if (!reply)
-    {
-        return false;
-    } else if (QNetworkReply::NoError != reply->error() ) {
-        qWarning() << "error fetching" << uri;
-        return false;
-    } else if (reply->error() == QNetworkReply::NoError) {
-        QFile file(filename);
-        if (file.open(QIODevice::WriteOnly)) {
-            file.write(reply->readAll());
-        } else {
-            qWarning() << "Fwupd Error: Cannot Open File to write Data" << filename;
-        }
-    }
-    return true;
-}
-
-void FwupdBackend::refreshRemote(FwupdBackend* backend, FwupdRemote* remote, quint64 cacheAge, GCancellable *cancellable)
-{
-    if (!fwupd_remote_get_filename_cache_sig(remote))
-    {
-        qWarning() << "Fwupd Error: " << "Remote " << fwupd_remote_get_id(remote) << "has no cache signature!";
-        return;
-    }
-
-    /* check cache age */
-    if (cacheAge > 0)
-    {
-        const quint64 age = fwupd_remote_get_age(remote);
-        if (age < cacheAge)
-        {
-//             qDebug() << "Fwupd Info:" << fwupd_remote_get_id(remote) << "is only" << age << "seconds old, so ignoring refresh! ";
-            return;
-        }
-    }
-
-    const QString cacheId = QStringLiteral("fwupd/remotes.d/%1").arg(QString::fromUtf8(fwupd_remote_get_id(remote)));
-    const auto basenameSig = QString::fromUtf8(g_path_get_basename(fwupd_remote_get_filename_cache_sig(remote)));
-    const QString filenameSig = cacheFile(cacheId, basenameSig);
-
-    if (filenameSig.isEmpty())
-        return;
-
-    /* download the signature first*/
-    const QUrl urlSig(QString::fromUtf8(fwupd_remote_get_metadata_uri_sig(remote)));
-    const QString filenameSigTmp(filenameSig + QStringLiteral(".tmp"));
-
-    if (!downloadFile(urlSig, filenameSigTmp)) {
-        qWarning() << "failed to download" << urlSig;
-        return;
-    }
-    Q_ASSERT(QFile::exists(filenameSigTmp));
-
-    const auto checksum = fwupd_remote_get_checksum(remote);
-    const QCryptographicHash::Algorithm hashAlgorithm = gchecksumToQChryptographicHash()[fwupd_checksum_guess_kind(checksum)];
-    const QByteArray hash = getChecksum(filenameSigTmp, hashAlgorithm);
-
-    const QByteArray oldHash = getChecksum(filenameSig, hashAlgorithm);
-    if (oldHash == hash) {
-        qDebug() << "remote hasn't changed:" << fwupd_remote_get_id(remote);
-        QFile::remove(filenameSigTmp);
-        return;
-    }
-
-    QFile::remove(filenameSig);
-
-    if (!QFile::rename(filenameSigTmp, filenameSig)) {
-        QFile::remove(filenameSigTmp);
-        qWarning() << "Fwupd Error: cannot save remote signature" << filenameSigTmp << "to" << filenameSig;
-        return;
-    }
-    QFile::remove(filenameSigTmp);
-
-    const auto basename = QString::fromUtf8(g_path_get_basename(fwupd_remote_get_filename_cache(remote)));
-    const QString filename = cacheFile(cacheId, basename);
-
-    if (filename.isEmpty())
-        return;
-
-    qDebug() << "Fwupd Info: saving new firmware metadata to:" <<  filename;
-
-    const QUrl url(QString::fromUtf8(fwupd_remote_get_metadata_uri(remote)));
-    if (!downloadFile(url, filename))
-    {
-        qWarning() << "Fwupd Error: cannot download file:" << filename;
-        return;
-    }
-
-    g_autoptr(GError) error = nullptr;
-    if (!fwupd_client_update_metadata(backend->client, fwupd_remote_get_id(remote), filename.toUtf8().constData(), filenameSig.toUtf8().constData(), cancellable, &error))
-    {
-        backend->handleError(error);
-    }
-}
-
 void FwupdBackend::handleError(GError *perror)
 {
-    //TODO: localise the error message
+    // TODO: localise the error message
     if (perror && !g_error_matches(perror, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE) && !g_error_matches(perror, FWUPD_ERROR, FWUPD_ERROR_NOTHING_TO_DO)) {
         const QString msg = QString::fromUtf8(perror->message);
-        QTimer::singleShot(0, this, [this, msg](){
+        QTimer::singleShot(0, this, [this, msg]() {
             Q_EMIT passiveMessage(msg);
         });
         qWarning() << "Fwupd Error" << perror->code << perror->message;
     }
-//     else
-//         qDebug() << "Fwupd skipped" << perror->code << perror->message;
+    // else
+    //     qDebug() << "Fwupd skipped" << perror->code << perror->message;
 }
 
 QString FwupdBackend::cacheFile(const QString &kind, const QString &basename)
@@ -349,8 +219,7 @@ QString FwupdBackend::cacheFile(const QString &kind, const QString &basename)
     const QDir cacheDir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation));
     const QString cacheDirFile = cacheDir.filePath(kind);
 
-    if (!QFileInfo::exists(cacheDirFile) && !cacheDir.mkpath(kind))
-    {
+    if (!QFileInfo::exists(cacheDirFile) && !cacheDir.mkpath(kind)) {
         qWarning() << "Fwupd Error: cannot make  cache directory!";
         return {};
     }
@@ -358,82 +227,110 @@ QString FwupdBackend::cacheFile(const QString &kind, const QString &basename)
     return cacheDir.filePath(kind + QLatin1Char('/') + basename);
 }
 
+static void fwupd_client_get_devices_cb(GObject * /*source*/, GAsyncResult *res, gpointer user_data)
+{
+    FwupdBackend *helper = (FwupdBackend *)user_data;
+    g_autoptr(GError) error = nullptr;
+    auto array = fwupd_client_get_devices_finish(helper->client, res, &error);
+    if (!error)
+        helper->setDevices(array);
+    else
+        helper->handleError(error);
+}
+
+void FwupdBackend::setDevices(GPtrArray *devices)
+{
+    for (uint i = 0; devices && i < devices->len; i++) {
+        FwupdDevice *device = (FwupdDevice *)g_ptr_array_index(devices, i);
+
+        if (!fwupd_device_has_flag(device, FWUPD_DEVICE_FLAG_SUPPORTED))
+            continue;
+
+        g_autoptr(GError) error = nullptr;
+        g_autoptr(GPtrArray) releases = fwupd_client_get_releases(client, fwupd_device_get_id(device), m_cancellable, &error);
+
+        if (error) {
+            if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED)) {
+                qWarning() << "fwupd: Device not supported:" << fwupd_device_get_name(device) << error->message;
+                continue;
+            }
+            if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE)) {
+                continue;
+            }
+
+            handleError(error);
+        }
+
+        auto res = new FwupdResource(device, this);
+        for (uint i = 0; releases && i < releases->len; ++i) {
+            FwupdRelease *release = (FwupdRelease *)g_ptr_array_index(releases, i);
+            if (res->installedVersion().toUtf8() == fwupd_release_get_version(release)) {
+                res->setReleaseDetails(release);
+                break;
+            }
+        }
+        addResource(res);
+    }
+    g_ptr_array_unref(devices);
+
+    addUpdates();
+
+    m_fetching = false;
+    Q_EMIT fetchingChanged();
+    Q_EMIT initialized();
+}
+
+static void fwupd_client_get_remotes_cb(GObject * /*source*/, GAsyncResult *res, gpointer user_data)
+{
+    FwupdBackend *helper = (FwupdBackend *)user_data;
+    g_autoptr(GError) error = nullptr;
+    auto array = fwupd_client_get_remotes_finish(helper->client, res, &error);
+    if (!error)
+        helper->setRemotes(array);
+    else
+        helper->handleError(error);
+}
+
+static void fwupd_client_refresh_remote_cb(GObject * /*source*/, GAsyncResult *res, gpointer user_data)
+{
+    FwupdBackend *helper = (FwupdBackend *)user_data;
+    g_autoptr(GError) error = nullptr;
+    const bool successful = fwupd_client_refresh_remote_finish(helper->client, res, &error);
+    if (!successful)
+        helper->handleError(error);
+}
+
+void FwupdBackend::setRemotes(GPtrArray *remotes)
+{
+    for (uint i = 0; remotes && i < remotes->len; i++) {
+        FwupdRemote *remote = (FwupdRemote *)g_ptr_array_index(remotes, i);
+        if (!fwupd_remote_get_enabled(remote))
+            continue;
+
+        if (fwupd_remote_get_kind(remote) == FWUPD_REMOTE_KIND_LOCAL)
+            continue;
+
+        fwupd_client_refresh_remote_async(client, remote, m_cancellable, fwupd_client_refresh_remote_cb, this);
+    }
+}
+
 void FwupdBackend::checkForUpdates()
 {
     if (m_fetching)
         return;
 
-    auto fw = new QFutureWatcher<GPtrArray*>(this);
-    connect(fw, &QFutureWatcher<GPtrArray*>::finished, this, [this, fw]() {
-        m_fetching = true;
-        emit fetchingChanged();
+    g_autoptr(GError) error = nullptr;
 
-        auto devices = fw->result();
-        for(uint i = 0; devices && i < devices->len; i++) {
-            FwupdDevice *device = (FwupdDevice *) g_ptr_array_index(devices, i);
+    if (!fwupd_client_connect(client, m_cancellable, &error)) {
+        handleError(error);
+        return;
+    }
 
-            if (!fwupd_device_has_flag (device, FWUPD_DEVICE_FLAG_SUPPORTED))
-                continue;
+    m_fetching = true;
+    Q_EMIT fetchingChanged();
 
-            g_autoptr(GError) error = nullptr;
-            g_autoptr(GPtrArray) releases = fwupd_client_get_releases(client, fwupd_device_get_id(device), m_cancellable, &error);
-
-            if (error) {
-                if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED)) {
-                    qWarning() << "fwupd: Device not supported:" << fwupd_device_get_name(device) << error->message;
-                    continue;
-                }
-                if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE)) {
-                    continue;
-                }
-
-                handleError(error);
-            }
-
-            auto res = createDevice(device);
-            for (uint i=0; releases && i<releases->len; ++i) {
-                FwupdRelease *release = (FwupdRelease *)g_ptr_array_index(releases, i);
-                if (res->installedVersion().toUtf8() == fwupd_release_get_version(release)) {
-                    res->setReleaseDetails(release);
-                    break;
-                }
-            }
-            addResourceToList(res);
-        }
-        g_ptr_array_unref(devices);
-
-        addUpdates();
-
-        m_fetching = false;
-        emit fetchingChanged();
-        emit initialized();
-        fw->deleteLater();
-    });
-    fw->setFuture(QtConcurrent::run(&m_threadPool, [this] () -> GPtrArray*
-        {
-            const uint cacheAge = (24*60*60); // Check for updates every day
-            g_autoptr(GError) error = nullptr;
-
-            /* get devices */
-            GPtrArray* devices = fwupd_client_get_devices(client, m_cancellable, &error);
-            handleError(error);
-
-            g_autoptr(GPtrArray) remotes = fwupd_client_get_remotes(client, m_cancellable, &error);
-            handleError(error);
-            for(uint i = 0; remotes && i < remotes->len; i++)
-            {
-                FwupdRemote *remote = (FwupdRemote *)g_ptr_array_index(remotes, i);
-                if (!fwupd_remote_get_enabled(remote))
-                    continue;
-
-                if (fwupd_remote_get_kind(remote) == FWUPD_REMOTE_KIND_LOCAL)
-                    continue;
-
-                refreshRemote(this, remote, cacheAge, m_cancellable);
-            }
-            return devices;
-        }
-    ));
+    fwupd_client_get_devices_async(client, m_cancellable, fwupd_client_get_devices_cb, this);
+    fwupd_client_get_remotes_async(client, m_cancellable, fwupd_client_get_remotes_cb, this);
 }
 
 int FwupdBackend::updatesCount() const
@@ -441,7 +338,7 @@ int FwupdBackend::updatesCount() const
     return m_updater->updatesCount();
 }
 
-ResultsStream* FwupdBackend::search(const AbstractResourcesBackend::Filters& filter)
+ResultsStream *FwupdBackend::search(const AbstractResourcesBackend::Filters &filter)
 {
     if (!filter.resourceUrl.isEmpty()) {
         if (filter.resourceUrl.scheme() == QLatin1String("fwupd")) {
@@ -453,13 +350,14 @@ ResultsStream* FwupdBackend::search(const AbstractResourcesBackend::Filters& fil
     }
 
     auto stream = new ResultsStream(QStringLiteral("FwupdStream"));
-    auto f = [this, stream, filter] () {
-        QVector<AbstractResource*> ret;
-        foreach(AbstractResource* r, m_resources) {
+    auto f = [this, stream, filter]() {
+        QVector<AbstractResource *> ret;
+        for (AbstractResource *r : qAsConst(m_resources)) {
             if (r->state() < filter.state)
                 continue;
 
-            if (filter.search.isEmpty() || r->name().contains(filter.search, Qt::CaseInsensitive) || r->comment().contains(filter.search, Qt::CaseInsensitive)) {
+            if (filter.search.isEmpty() || r->name().contains(filter.search, Qt::CaseInsensitive)
+                || r->comment().contains(filter.search, Qt::CaseInsensitive)) {
                 ret += r;
             }
         }
@@ -475,45 +373,43 @@ ResultsStream* FwupdBackend::search(const AbstractResourcesBackend::Filters& fil
     return stream;
 }
 
-ResultsStream * FwupdBackend::findResourceByPackageName(const QUrl& search)
+ResultsStream *FwupdBackend::findResourceByPackageName(const QUrl &search)
 {
     auto res = search.scheme() == QLatin1String("fwupd") ? m_resources.value(search.host().replace(QLatin1Char('.'), QLatin1Char(' '))) : nullptr;
-    if (!res)
-    {
+    if (!res) {
         return new ResultsStream(QStringLiteral("FwupdStream"), {});
-    }
-    else
-        return new ResultsStream(QStringLiteral("FwupdStream"), { res });
+    } else
+        return new ResultsStream(QStringLiteral("FwupdStream"), {res});
 }
 
-AbstractBackendUpdater* FwupdBackend::backendUpdater() const
+AbstractBackendUpdater *FwupdBackend::backendUpdater() const
 {
     return m_updater;
 }
 
-AbstractReviewsBackend* FwupdBackend::reviewsBackend() const
+AbstractReviewsBackend *FwupdBackend::reviewsBackend() const
 {
     return nullptr;
 }
 
-Transaction* FwupdBackend::installApplication(AbstractResource* app, const AddonList& addons)
+Transaction *FwupdBackend::installApplication(AbstractResource *app, const AddonList &addons)
 {
     Q_ASSERT(addons.isEmpty());
     return installApplication(app);
 }
 
-Transaction* FwupdBackend::installApplication(AbstractResource* app)
+Transaction *FwupdBackend::installApplication(AbstractResource *app)
 {
-	return new FwupdTransaction(qobject_cast<FwupdResource*>(app), this);
+    return new FwupdTransaction(qobject_cast<FwupdResource *>(app), this);
 }
 
-Transaction* FwupdBackend::removeApplication(AbstractResource* /*app*/)
+Transaction *FwupdBackend::removeApplication(AbstractResource * /*app*/)
 {
     qWarning() << "should not have reached here, it's not possible to uninstall a firmware";
     return nullptr;
 }
 
-ResultsStream* FwupdBackend::resourceForFile(const QUrl& path)
+ResultsStream *FwupdBackend::resourceForFile(const QUrl &path)
 {
     if (!path.isLocalFile())
         return new ResultsStream(QStringLiteral("FwupdStream-void"), {});
@@ -523,30 +419,25 @@ ResultsStream* FwupdBackend::resourceForFile(const QUrl& path)
     const QString fileName = path.fileName();
     QMimeDatabase db;
     QMimeType type = db.mimeTypeForFile(fileName);
-    FwupdResource* app = nullptr;
+    FwupdResource *app = nullptr;
 
-    if (type.isValid() && type.inherits(QStringLiteral("application/vnd.ms-cab-compressed")))
-    {
+    if (type.isValid() && type.inherits(QStringLiteral("application/vnd.ms-cab-compressed"))) {
         g_autofree gchar *filename = fileName.toUtf8().data();
         g_autoptr(GPtrArray) devices = fwupd_client_get_details(client, filename, nullptr, &error);
 
-        if (devices)
-        {
+        if (devices) {
             FwupdDevice *device = (FwupdDevice *)g_ptr_array_index(devices, 0);
             app = createRelease(device);
             app->setState(AbstractResource::None);
-            for(uint i = 1; i < devices->len; i++)
-            {
+            for (uint i = 1; i < devices->len; i++) {
                 FwupdDevice *device = (FwupdDevice *)g_ptr_array_index(devices, i);
-                FwupdResource* app_ = createRelease(device);
+                FwupdResource *app_ = createRelease(device);
                 app_->setState(AbstractResource::None);
             }
-            addResourceToList(app);
+            addResource(app);
             connect(app, &FwupdResource::stateChanged, this, &FwupdBackend::updatesCountChanged);
             return new ResultsStream(QStringLiteral("FwupdStream-file"), {app});
-        }
-        else
-        {
+        } else {
             handleError(error);
         }
     }
