@@ -7,9 +7,10 @@
 #include "AbstractBackendUpdater.h"
 #include "AbstractResource.h"
 
-AbstractBackendUpdater::AbstractBackendUpdater(QObject* parent)
+AbstractBackendUpdater::AbstractBackendUpdater(QObject *parent)
     : QObject(parent)
-{}
+{
+}
 
 void AbstractBackendUpdater::cancel()
 {
@@ -19,7 +20,8 @@ void AbstractBackendUpdater::cancel()
 
 void AbstractBackendUpdater::fetchChangelog() const
 {
-    foreach(auto res, toUpdate()) {
+    const auto toUpd = toUpdate();
+    for (auto res : toUpd) {
         res->fetchChangelog();
     }
 }
@@ -33,7 +35,22 @@ void AbstractBackendUpdater::enableNeedsReboot()
     Q_EMIT needsRebootChanged();
 }
 
+void AbstractBackendUpdater::enableReadyToReboot()
+{
+    m_readyToReboot = true;
+}
+
 bool AbstractBackendUpdater::needsReboot() const
 {
     return m_needsReboot;
 }
+
+bool AbstractBackendUpdater::isReadyToReboot() const
+{
+    return m_readyToReboot;
+}
+
+void AbstractBackendUpdater::setOfflineUpdates(bool useOfflineUpdates)
+{
+    Q_UNUSED(useOfflineUpdates);
+}
